#
# spec file for package google-guest-configs
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550 && 0%{?sle_version} <= 150300
%define _udevdir %(pkg-config --variable udevdir udev)
%define _modprobedir /lib/modprobe.d
%else
%define _udevdir %(pkg-config --variable udev_dir udev)
%endif
%global modprobe_d_files gce-blacklist.conf

Name:           google-guest-configs
Version:        20220211.00
Release:        150400.13.3.1
Summary:        Google Cloud Guest Configs
License:        Apache-2.0
Group:          System/Daemons
URL:            https://github.com/GoogleCloudPlatform/guest-configs
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  systemd-rpm-macros
%if 0%{?suse_version} && 0%{?suse_version} <= 1315
BuildRequires:  pkg-config
%endif
BuildRequires:  pkgconfig(udev)
Requires:       nvme-cli
BuildArch:      noarch

%description
Google Cloud Guest Configs

%prep
%setup -q -n guest-configs-%{version}

%build
# Nothing to build

%install
mkdir -p %{buildroot}%{_modprobedir}
cp -av src/etc/modprobe.d/* %{buildroot}%{_modprobedir}
mkdir -p %{buildroot}%{_sysconfdir}/rsyslog.d
cp -av src/etc/rsyslog.d/* %{buildroot}%{_sysconfdir}/rsyslog.d/
mkdir -p %{buildroot}%{_sysctldir}
cp -av src/etc/sysctl.d/* %{buildroot}%{_sysctldir}
mkdir -p %{buildroot}%{_udevrulesdir}
cp -av src/lib/udev/rules.d/* %{buildroot}%{_udevrulesdir}/
cp -av src/lib/udev/google_nvme_id %{buildroot}/%{_udevdir}/
mkdir -p %{buildroot}%{_bindir}
cp -av src/usr/bin/* %{buildroot}%{_bindir}/

%pre
# Avoid restoring outdated stuff in posttrans
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -f "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}.rpmsave.old" || :
done

%posttrans
# Migration of modprobe.conf files to _modprobedir
for _f in %{?modprobe_d_files}; do
    [ ! -f "/etc/modprobe.d/${_f}.rpmsave" ] || \
        mv -fv "/etc/modprobe.d/${_f}.rpmsave" "/etc/modprobe.d/${_f}" || :
done

%files
%defattr(0644,root,root,0755)
%doc README.md
%license LICENSE
%attr(0755,root,root) %{_bindir}/google_optimize_local_ssd
%exclude %attr(0755,root,root) %{_bindir}/google_set_hostname
%attr(0755,root,root) %{_bindir}/google_set_multiqueue
%dir %{_modprobedir}
%{_modprobedir}/gce-blacklist.conf
%dir %{_sysconfdir}/rsyslog.d
%config %{_sysconfdir}/rsyslog.d/*
%{_sysctldir}/*
%attr(0755,root,root) %{_udevdir}/google_nvme_id
%{_udevrulesdir}/*

%changelog
* Tue Oct 11 2022 adrian.glaubitz@suse.com
- Add nvme-cli to Requires (bsc#1204068, bsc#1204091)
* Fri Mar  4 2022 mwilck@suse.com
- install modprobe.d files to /lib/modprobe.d on SLE (bsc#1196275, jsc#SLE-20639)
* Mon Feb 14 2022 adrian.glaubitz@suse.com
- Update to version 20220211.00 (bsc#1195437, bsc#1195438)
  * Set NVMe-PD IO timeout to 4294967295. (#32)
* Fri Dec 17 2021 adrian.glaubitz@suse.com
- Add missing pkg-config dependency to BuildRequires for SLE-12
* Tue Dec  7 2021 adrian.glaubitz@suse.com
- Install modprobe configuration files into /etc again on SLE-15-SP2 and
  older since that's stil the default location on these distributions
- Probe udev directory using the "udevdir" pkg-config variable on SLE-15-SP2
  and older since the variable got renamed to "udev_dir" in later versions
- Remove redundant pkgconfig(udev) from BuildRequires for SLE-12
* Thu Nov 18 2021 adrian.glaubitz@suse.com
- Update to version 20211116.00 (bsc#1193257, bsc#1193258)
  * GCE supports up to 24 NVMe local SSDs, but the regex in the PROGRAM field
    only looks for the last digit of the given string causing issues when there
    are >= 10 local SSDs. Changed REGEX to get the last number of the string
    instead to support the up to 24 local SSDs. (#30)
  * chmod+x google_nvme_id on EL (#31)
- Fix duplicate installation of google_optimize_local_ssd and google_set_multiqueue
- Install google_nvme_id into /usr/lib/udev (bsc#1192652, bsc#1192653)
* Fri Oct 22 2021 adrian.glaubitz@suse.com
- Update to version 20210916.00
  * Revert "dont set IP in etc/hosts; remove rsyslog (#26)" (#28)
- from version 20210831.00
  * restore rsyslog (#27)
- from version 20210830.00
  * Fix NVMe partition names (#25)
- from version 20210824.00
  * dont set IP in etc/hosts; remove rsyslog (#26)
  * update OWNERS
* Fri Aug 20 2021 gmbr3@opensuse.org
- Use %%_modprobedir for modprobe.d files (out of /etc)
- Use %%_sysctldir for sysctl.d files (out of /etc)
* Mon Jul 19 2021 adrian.glaubitz@suse.com
- Update to version 20210702.00
  * use grep for hostname check (#23)
- from version 20210629.00
  * address set_hostname vuln (#22)
- from version 20210324.00
  * dracut.conf wants spaces around values (#19)
* Wed Mar 31 2021 adrian.glaubitz@suse.com
- Update to version 20210317.00 (bsc#1183414, bsc#1183415)
  * dracut.conf wants spaces around values (#19)
  * make the same change for debian (#18)
  * change path back for google_nvme_id (#17)
  * move google_nvme_id to /usr/bin (#16)
  * correct udev rule syntax (#15)
  * prune el6 spec (#13)
  * Updated udev rules (#11)
- Remove empty %%{_sbindir} from %%install and %%files section
* Tue Jan  5 2021 rjschwei@suse.com
- Remove service files (bsc#1180304)
  + google-optimize-local-ssd.service, google-set-multiqueue.service
    scripts are called from within the guest agent
* Tue Aug 25 2020 adrian.glaubitz@suse.com
- Update to version 20200626.00 (bsc#1175740, bsc#1175741)
  * Updates the udev rules for local SSD disks. (#9)
  * Fix tx affinity logic when number of CPUs is above 32 (#6)
* Fri Jul 24 2020 rjschwei@suse.com
- Switch udev requires to pkgconfig to allow the build service to use
  the -mini package for build optimization
* Wed Jul 22 2020 adrian.glaubitz@suse.com
- Initial build (bsc#1174304, bsc#1174306, jsc#ECO-2099, jsc#PM-1945)
  + Version 20200626.00
  + Replaces configuration from google-compute-engine-{init,oslogin} package
